import { cloneElement, Component } from 'react';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

/**
 * chunkify splits an array in groups of len items
 * @param arr
 * @param len
 */
function chunkify(arr, len) {
    return arr.reduce(function (prev, _, i) {
        if (i % len === 0) {
            prev.push(arr.slice(i, i + len));
        }
        return prev;
    }, []);
}
/**
 * getCharArray removes every space and obtains an array of characters in the
 * order they appear in the sentence.
 * @param sentence The sentence to split into chars
 */
var getCharArray = function (sentence) {
    return sentence
        .split(' ')
        .join('')
        .split('');
};

var MatrixText = /** @class */ (function (_super) {
    __extends(MatrixText, _super);
    function MatrixText() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.handleRenderColumns = function (charsForRow, rowIndex) {
            var _a = _this.props, getColumnKey = _a.getColumnKey, renderColumn = _a.renderColumn;
            return charsForRow.map(function (char, columnIndex) {
                var key = getColumnKey(char, rowIndex, columnIndex);
                return cloneElement(renderColumn(char, rowIndex, columnIndex), { key: key });
            });
        };
        _this.handleRenderRow = function (charsForRow, rowIndex) {
            var _a = _this.props, getRowKey = _a.getRowKey, renderRow = _a.renderRow;
            var key = getRowKey(charsForRow, rowIndex);
            var ColumnComponents = _this.handleRenderColumns(charsForRow, rowIndex);
            return cloneElement(renderRow(ColumnComponents, rowIndex), { key: key });
        };
        return _this;
    }
    MatrixText.prototype.render = function () {
        return this.chunks.map(this.handleRenderRow);
    };
    Object.defineProperty(MatrixText.prototype, "chunks", {
        get: function () {
            var _a = this.props, columns = _a.columns, sentence = _a.sentence;
            return chunkify(getCharArray(sentence), columns);
        },
        enumerable: true,
        configurable: true
    });
    MatrixText.getColumnKeyDefault = function (char, rowIndex, columnIndex) {
        return "column_" + rowIndex + "_" + columnIndex + "_" + char;
    };
    MatrixText.getRowKeyDefault = function (charsForRow, rowIndex) {
        return "row_" + rowIndex + "_" + charsForRow.join('');
    };
    MatrixText.defaultProps = {
        columns: 3,
        getColumnKey: MatrixText.getColumnKeyDefault,
        getRowKey: MatrixText.getRowKeyDefault,
        sentence: '',
    };
    return MatrixText;
}(Component));

export default MatrixText;
